@@ -19,6 +19,10 @@
 
 #include "Package.h"
 
+#include <fstream>
+
+#include <Lum/Base/String.h>
+
 #include <Lum/Panel.h>
 #include <Lum/Text.h>
 
@@ -141,9 +145,31 @@ size_t Package::GetInstalledSize() const
   return installedSize;
 }
 
-PackageEntry::PackageEntry(Lum::Model::ListTable *table, Package* package)
- : Lum::Model::ListTable::Entry(table),
-   package(package),
+bool Package::LoadPackageContent(std::list<std::wstring>& content)
+{
+  content.clear();
+
+  std::ifstream file;
+  std::string   line;
+
+  file.open(Lum::Base::WStringToString(L"/var/lib/dpkg/info/"+name+L".list").c_str(),std::ios::in);
+
+  if (!file) {
+    std::cerr << "Cannot open package file list!" << std::endl;
+    return false;
+  }
+
+  while (std::getline(file,line)) {
+    content.push_back(Lum::Base::StringToWString(line));
+  }
+
+  file.close();
+
+  return true;
+}
+
+PackageEntry::PackageEntry(Package* package)
+ : package(package),
    nameObject(NULL)
 {
 }
@@ -161,8 +187,7 @@ Lum::Object* PackageEntry::GetObject(size_t column) const
       Lum::Panel *panel;
       Lum::Text  *text;
 
-      panel=new Lum::VPanel();
-      panel->SetFlex(true,true);
+      panel=Lum::VPanel::Create(true,true);
 
       text=new Lum::Text();
       text->SetFlex(true,true);
@@ -170,16 +195,14 @@ Lum::Object* PackageEntry::GetObject(size_t column) const
       text->AddText(L" (");
       text->AddText(package->GetSection(),
                     Lum::OS::Font::normal,
-                    Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                              Lum::OS::Display::fontScaleFootnote));
+                    Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote));
       text->AddText(L")");
       panel->Add(text);
 
       text=new Lum::Text(package->GetShortDescription(),
                          Lum::OS::Font::italic,
                          Lum::Text::left,
-                         Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                                   Lum::OS::Display::fontScaleFootnote));
+                         Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote));
       text->SetFlex(true,true);
       panel->Add(text);
 
@@ -203,11 +226,6 @@ std::wstring PackageEntry::GetString(size_t column) const
   }
 }
 
-bool PackageEntry::IsGreater(const Entry* other, size_t column) const
-{
-  return package->GetName()>dynamic_cast<const PackageEntry*>(other)->package->GetName();
-}
-
 Package* PackageEntry::GetPackage() const
 {
   return package;
